@@ -31,8 +31,7 @@
 #define ACTIVE_BG	"#ececec"
 #define SELECT_BG	"#c3c3c3"
 #define TROUGH		"#b3b3b3"
-#define CHECK_INDICATOR	WHITE
-#define MENU_INDICATOR  BLACK
+#define INDICATOR	WHITE
 #define DISABLED	"#a3a3a3"
 
 /*
@@ -55,6 +54,7 @@
 #define DEF_BUTTON_DEFAULT		"disabled"
 #define DEF_BUTTON_DISABLED_FG_COLOR	DISABLED
 #define DEF_BUTTON_DISABLED_FG_MONO	""
+#define DEF_LABEL_FG			BLACK
 #define DEF_BUTTON_FG			BLACK
 #define DEF_CHKRAD_FG			DEF_BUTTON_FG
 #define DEF_BUTTON_FONT			"TkDefaultFont"
@@ -79,7 +79,7 @@
 #define DEF_LABCHKRAD_RELIEF		"flat"
 #define DEF_BUTTON_REPEAT_DELAY		"0"
 #define DEF_BUTTON_REPEAT_INTERVAL	"0"
-#define DEF_BUTTON_SELECT_COLOR		CHECK_INDICATOR
+#define DEF_BUTTON_SELECT_COLOR		INDICATOR
 #define DEF_BUTTON_SELECT_MONO		BLACK
 #define DEF_BUTTON_SELECT_IMAGE		((char *) NULL)
 #define DEF_BUTTON_STATE		"normal"
@@ -244,7 +244,7 @@
 #define DEF_MENU_ENTRY_ACTIVE_FG	((char *) NULL)
 #define DEF_MENU_ENTRY_ACCELERATOR	((char *) NULL)
 #define DEF_MENU_ENTRY_BG		((char *) NULL)
-#define DEF_MENU_ENTRY_BITMAP		None
+#define DEF_MENU_ENTRY_BITMAP		NULL
 #define DEF_MENU_ENTRY_COLUMN_BREAK	"0"
 #define DEF_MENU_ENTRY_COMMAND		((char *) NULL)
 #define DEF_MENU_ENTRY_COMPOUND 	"none"
@@ -284,7 +284,7 @@
 #define DEF_MENU_FG			BLACK
 #define DEF_MENU_POST_COMMAND		""
 #define DEF_MENU_RELIEF			"raised"
-#define DEF_MENU_SELECT_COLOR		MENU_INDICATOR
+#define DEF_MENU_SELECT_COLOR		BLACK
 #define DEF_MENU_SELECT_MONO		BLACK
 #define DEF_MENU_TAKE_FOCUS		"0"
 #define DEF_MENU_TEAROFF		"1"
@@ -486,7 +486,7 @@
 #define DEF_TEXT_PADX			"1"
 #define DEF_TEXT_PADY			"1"
 #define DEF_TEXT_RELIEF			"sunken"
-#define DEF_TEXT_INACTIVE_SELECT_COLOR	SELECT_BG
+#define DEF_TEXT_INACTIVE_SELECT_BG_COLOR	SELECT_BG
 #define DEF_TEXT_SELECT_COLOR		SELECT_BG
 #define DEF_TEXT_SELECT_MONO		BLACK
 #define DEF_TEXT_SELECT_BD_COLOR	"0"
@@ -514,6 +514,14 @@
 
 #define DEF_CANVTEXT_FONT		"TkDefaultFont"
 
+/*
+ * Defaults for canvas items
+ * (arcs, bitmaps, lines, polygons, rectangles, and ovals):
+ */
+
+#define DEF_CANVBMAP_FG			BLACK
+#define DEF_CANVITEM_OUTLINE		BLACK
+
 /*
  * Defaults for toplevels (most of the defaults for frames also apply
  * to toplevels):
